﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;

namespace WC_ColumnAndScatter
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraChart1.ChartType = ChartType.Composite;
            ChartArea myChartArea = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(myChartArea);

            AxisItem axisXColumn = new AxisItem();
            axisXColumn.OrientationType = AxisNumber.X_Axis;
            axisXColumn.DataType = AxisDataType.String;
            axisXColumn.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisXColumn.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisXColumn.Labels.Orientation = TextOrientation.VerticalLeftFacing;

            AxisItem axisXLine = new AxisItem();
            axisXLine.OrientationType = AxisNumber.X_Axis;
            axisXLine.DataType = AxisDataType.String;
            axisXLine.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            axisXLine.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisXLine.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisXLine.Visible = false;
            axisXLine.Labels.Visible = false;
            //set margins in order to display the line chart over the column chart
            axisXLine.Margin.Near.MarginType = LocationType.RowColumn;
            axisXLine.Margin.Near.Value = 0.4;
            axisXLine.Margin.Far.MarginType = LocationType.RowColumn;
            axisXLine.Margin.Far.Value = 0.4;

            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = 0;
            axisY.RangeMax = 8;

            myChartArea.Axes.Add(axisXColumn);
            myChartArea.Axes.Add(axisXLine);
            myChartArea.Axes.Add(axisY);

            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ColumnChart;
            myColumnLayer.ChartArea = myChartArea;
            myColumnLayer.AxisX = axisXColumn;
            myColumnLayer.AxisY = axisY;

            NumericSeries columnSeries = new NumericSeries();
            DataTable columnTable = GetColumnData();
            columnSeries.DataBind(columnTable, "Value Column","Label Column");
            this.ultraChart1.CompositeChart.Series.Add(columnSeries);
            myColumnLayer.Series.Add(columnSeries);

            ChartLayerAppearance myLineLayer = new ChartLayerAppearance();
            myLineLayer.ChartType = ChartType.LineChart;
            myLineLayer.ChartArea = myChartArea;
            LineAppearance app = new LineAppearance();
            app.IconAppearance.Icon = SymbolIcon.Diamond;
            ((LineChartAppearance)myLineLayer.ChartTypeAppearance).LineAppearances.Add(app);
            myLineLayer.AxisY = axisY;
            myLineLayer.AxisX = axisXLine;

            NumericSeries lineSeries = new NumericSeries();
            lineSeries.PEs.Add(new PaintElement(Color.Blue));
            DataTable lineTable = getScatterData();
            lineSeries.DataBind(lineTable, "YValues", "XValues");
            this.ultraChart1.CompositeChart.Series.Add(lineSeries);
            myLineLayer.Series.Add(lineSeries);

            this.ultraChart1.CompositeChart.ChartLayers.Add(myLineLayer);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);
        }

        private DataTable GetColumnData()
        {
            DataTable columnTable = new DataTable();
            columnTable.Columns.Add("Label Column", typeof(string));
            columnTable.Columns.Add("Value Column", typeof(double));
            columnTable.Columns.Add("Another Value Column", typeof(double));
            columnTable.Rows.Add(new object[] { "Point A", 1.0, 3.0 });
            columnTable.Rows.Add(new object[] { "Point B", 2.0, 2.0 });
            columnTable.Rows.Add(new object[] { "Point C", 3.0, 1.0 });
            columnTable.Rows.Add(new object[] { "Point D", 4.0, 2.0 });
            columnTable.Rows.Add(new object[] { "Point E", 5.0, 3.0 });
            return columnTable;
        }

        private DataTable getScatterData()
        {
            DataTable scatterTable = new DataTable();

            scatterTable.Columns.Add("XValues", typeof(int));
            scatterTable.Columns.Add("YValues", typeof(int));

            scatterTable.Rows.Add(new object[] { 0, 1 });
            scatterTable.Rows.Add(new object[] { 1, 3 });
            scatterTable.Rows.Add(new object[] { 2, 6 });
            scatterTable.Rows.Add(new object[] { 3, 7 });
            scatterTable.Rows.Add(new object[] { 4, 4 });

            return scatterTable;
        }
    }
}
